==> saenopy-1.0.5.tar.gz: saenopy-1.0.5/README.md <==
SAENOPY
=======

[![DOC](https://readthedocs.org/projects/saenopy/badge/)](https://saenopy.readthedocs.io)
[![Coverage Status](https://coveralls.io/repos/github/rgerum/saenopy/badge.svg?branch=master)](https://coveralls.io/github/rgerum/saenopy?branch=master)
[![PyTest](https://github.com/rgerum/saenopy/actions/workflows/test.yml/badge.svg)](https://github.com/rgerum/saenopy/actions/workflows/test.yml)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

<p align="center">
  <img src="saenopy/img/Logo.png" />
</p>


SAENOPY is a free open source 3D traction force microscopy software. Its material model is especially well suited for
tissue-mimicking and typically highly non-linear biopolymer matrices such as collagen, fibrin, or Matrigel. 

It features a python package to use in scripts and an extensive graphical user interface.

Check out our [Documentation](https://saenopy.readthedocs.io) on how to install and use it.

## Installation

### Standalone
To use saenopy without a complicated installation you can use our standalone binaries to get started right away on Windows or Linux.

Windows
https://github.com/rgerum/saenopy/releases/download/v1.0.4/saenopy.exe

Linux
https://github.com/rgerum/saenopy/releases/download/v1.0.4/saenopy

### Using Python

If you are experienced with python or even want to use our Python API, you need to install saenopy as a python package.
Saenopy can be installed directly using pip:

    ``pip install saenopy``

Now you can start the user interface with:

    ``saenopy``

## Getting started
To get started you can have a look at our collection of [example datasets](https://saenopy.readthedocs.io/en/latest/auto_examples/index.html).

## Preprint
If you want to cite saenopy you can reference our preprint.

*Dynamic traction force measurements of migrating immune cells in 3D matrices*
David Böhringer, Mar Cóndor, Lars Bischof, Tina Czerwinski, Andreas Bauer, Caroline Voskens, Silvia Budday, 
Christoph Mark, Ben Fabry, Richard Gerum
**bioRxiv 2022.11.16.516758**; doi: https://doi.org/10.1101/2022.11.16.516758

==> saenopy-1.0.6.tar.gz: saenopy-1.0.6/README.md <==
SAENOPY: 3D Traction Force Microscopy with Python
=======

[![DOC](https://readthedocs.org/projects/saenopy/badge/)](https://saenopy.readthedocs.io)
[![Coverage Status](https://coveralls.io/repos/github/rgerum/saenopy/badge.svg?branch=master)](https://coveralls.io/github/rgerum/saenopy?branch=master)
[![PyTest](https://github.com/rgerum/saenopy/actions/workflows/test.yml/badge.svg)](https://github.com/rgerum/saenopy/actions/workflows/test.yml)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

<p align="center">
  <img src="saenopy/img/Logo.png" />
</p>


SAENOPY is a free open source 3D traction force microscopy (TFM) software. Its material model is especially well suited for
tissue-mimicking and typically highly non-linear biopolymer matrices such as collagen, fibrin, or Matrigel. 

It features a python package to use in scripts and an extensive graphical user interface.

Check out our [Documentation](https://saenopy.readthedocs.io) on how to install and use it.

## Installation

### Standalone
To use saenopy without a complicated installation you can use our standalone binaries to get started right away on Windows or Linux.

Windows
https://github.com/rgerum/saenopy/releases/download/v1.0.6/saenopy.exe

Linux
https://github.com/rgerum/saenopy/releases/download/v1.0.6/saenopy

### Using Python

If you are experienced with python or even want to use our Python API, you need to install saenopy as a python package.
Saenopy can be installed directly using pip:

    ``pip install saenopy``

Now you can start the user interface with:

    ``saenopy``

Or by executing the script “gui_master.py” in your python interpreter.

## Getting started
To get started you can have a look at our collection of [example datasets](https://saenopy.readthedocs.io/en/latest/auto_examples/index.html).

## Preprint
If you want to cite saenopy you can reference our preprint.

*Dynamic traction force measurements of migrating immune cells in 3D matrices*
David Böhringer, Mar Cóndor, Lars Bischof, Tina Czerwinski, Andreas Bauer, Caroline Voskens, Silvia Budday, 
Christoph Mark, Ben Fabry, Richard Gerum
**bioRxiv 2022.11.16.516758**; doi: https://doi.org/10.1101/2022.11.16.516758
